==> haskell-roman-numerals-0.5.1.5-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-KqgNMkNFmEs7zGK1YyKvuj
key:                  roman-numerals-0.5.1.5-KqgNMkNFmEs7zGK1YyKvuj
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  5eaee3d412cd47eee100b8ea4f59948f
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-8.10.2/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/roman-numerals-0.5.1.5
hs-libraries:         HSroman-numerals-0.5.1.5-KqgNMkNFmEs7zGK1YyKvuj
depends:
    base-4.14.1.0 base-unicode-symbols-0.2.4.2-FaV73MYXvpi9Ddr0Xr7reE
    bytestring-0.10.10.0 text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-roman-numerals-0.5.1.5-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-F7aR4svhfGU9euDXnis64L
key:                  roman-numerals-0.5.1.5-F7aR4svhfGU9euDXnis64L
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  d90076c3c8ed28b08735703824f3b3b1
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-8.10.3/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/roman-numerals-0.5.1.5
hs-libraries:         HSroman-numerals-0.5.1.5-F7aR4svhfGU9euDXnis64L
depends:
    base-4.14.1.0 base-unicode-symbols-0.2.4.2-FaV73MYXvpi9Ddr0Xr7reE
    bytestring-0.10.12.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
